Installation
============

TODO

If you want to install *articubench* the easiest way is to install it
from `pypi <https://pypi.python.org/pypi>`_ with:

.. code:: bash

    pip install --user articubench

